Meter

Enum Meter 

pub enum Meter {
    Standard(LyricalMeter),
    Other(OtherMeter),
}
Enum representing any type of meter, either standard or other.

Variants

Implementations

Source

impl Meter

pub fn is_same_type(&self, other: &Meter) -> bool

Checks if two meters are of the same type.

pub fn as_standard(&self) -> Option<&LyricalMeter>

Converts the Meter into a LyricalMeter if it is Standard.

pub fn as_other(&self) -> Option<&OtherMeter>

Converts the Meter into an OtherMeter if it is Other.