OtherMeter

Enum OtherMeter 

pub enum OtherMeter {
    FreeVerse,
    ClimbingRhyme,
    FallingRhyme,
    MixedMeter,
    BlankVerse,
}
Enum for other types of meters that don’t fit into the regular pattern.

Variants



FreeVerse



ClimbingRhyme



FallingRhyme



MixedMeter



BlankVerse

Implementations

Source

impl OtherMeter

pub fn is_free_verse(&self) -> bool

Returns true if the meter is considered free verse.

pub fn is_blank_verse(&self) -> bool

Returns true if the meter is considered blank verse.