pub struct LyricalMeter { /* private fields */ }Implementations
Sourceimpl LyricalMeter
impl LyricalMeter
pub fn random_with_env<ENV>() -> Self
pub fn random_uniform_with_env<ENV>() -> Self
Sourceimpl LyricalMeter
impl LyricalMeter
Sourcepub fn builder() -> LyricalMeterBuilder
pub fn builder() -> LyricalMeterBuilder
Starts building a LyricalMeter using the builder pattern without any initial arguments.
Sourcepub fn foot(&self) -> &MetricalFoot
pub fn foot(&self) -> &MetricalFoot
Returns a reference to the metrical foot.
Sourcepub fn length(&self) -> Option<&LineLength>
pub fn length(&self) -> Option<&LineLength>
Returns an optional reference to the line length, if it exists.
Sourcepub fn set_foot(&mut self, foot: MetricalFoot) -> &mut Self
pub fn set_foot(&mut self, foot: MetricalFoot) -> &mut Self
Sets the metrical foot.
Sourcepub fn set_length(&mut self, length: Option<LineLength>) -> &mut Self
pub fn set_length(&mut self, length: Option<LineLength>) -> &mut Self
Sets the line length.