pub enum Meter {
Standard(LyricalMeter),
Other(OtherMeter),
}Expand description
Enum representing any type of meter, either standard or other.
Variants
Standard(LyricalMeter)
Other(OtherMeter)
Implementations
Sourceimpl Meter
impl Meter
Sourcepub fn is_same_type(&self, other: &Meter) -> bool
pub fn is_same_type(&self, other: &Meter) -> bool
Checks if two meters are of the same type.
Sourcepub fn as_standard(&self) -> Option<&LyricalMeter>
pub fn as_standard(&self) -> Option<&LyricalMeter>
Converts the Meter into a LyricalMeter if it is Standard.
Sourcepub fn as_other(&self) -> Option<&OtherMeter>
pub fn as_other(&self) -> Option<&OtherMeter>
Converts the Meter into an OtherMeter if it is Other.